[yocto] [[AUH] 14/17] upgradehelper.py: Changed retry failure build to 30 days.

Aníbal Limón anibal.limon at linux.intel.com
Wed Nov 25 16:00:43 PST 2015


When build fails is stored into history fail that enables
to don't try to build again in a period of time, so
change that period to 30 days since the work patches will
be publish in web server.

Signed-off-by: Aníbal Limón <anibal.limon at linux.intel.com>
---
 upgradehelper.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/upgradehelper.py b/upgradehelper.py
index 18db9eb..6cf8dd0 100755
--- a/upgradehelper.py
+++ b/upgradehelper.py
@@ -738,12 +738,12 @@ class UniverseUpdater(Updater):
                     date.toordinal(date.today()) - \
                     date.toordinal(datetime.strptime(self.history[pn][2], '%Y-%m-%d'))
                 # retry recipes that had fetch errors or other errors after
                 # more than 7 days
                 if (self.history[pn][3] == str(FetchError()) or
-                        self.history[pn][3] == str(Error())) and retry_delta > 7:
+                        self.history[pn][3] == str(Error())) and retry_delta > 30:
                     return True
 
-                D(" Skipping upgrade of %s: is in history and not 7 days passed" % pn)
+                D(" Skipping upgrade of %s: is in history and not 30 days passed" % pn)
                 return False
 
         # drop native/cross/cross-canadian recipes. We deal with native
@@ -738,12 +738,12 @@ class UniverseUpdater(Updater):
                     date.toordinal(datetime.strptime(self.history[pn][2], '%Y-%m-%d'))
                 # retry recipes that had fetch errors or other errors after
-                # more than 7 days
+                # more than 30 days
                 if (self.history[pn][3] == str(FetchError()) or
-- 
2.1.4




More information about the yocto mailing list